/*
                            Preset V3D Models List

	Used with editor's create model input dialog.
 */

#ifndef VMAPRESETMODELS_H
#define VMAPRESETMODELS_H

#include <sys/types.h>
#include <gtk/gtk.h>

#include "v3dmodel.h"

#ifndef gbool
# define gbool	gboolean
#endif

/*
 *	Preest V3D Models List structure:
 */
typedef struct {

	gbool initialized;

	v3d_model_struct **model;
        int total_models;

} vma_preset_models_struct;

extern vma_preset_models_struct vma_preset_models;

extern int VMAPresetModelsLoad(void *core, vma_preset_models_struct *list);
extern void VMAPresetModelsUnload(void *core, vma_preset_models_struct *list);


#endif	/* VMAPRESETMODELS_H */
